@@ -2,10 +2,6 @@
 ( cd opt/kde/share/doc/HTML/cs/kdm ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
 ( cd opt/kde/share/doc/HTML/cs/konsole ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/cs/konsole ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/khelpcenter/quickstart ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/khelpcenter/quickstart ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
-( cd opt/kde/share/doc/HTML/cs/khelpcenter ; rm -rf common )
-( cd opt/kde/share/doc/HTML/cs/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
 ( cd opt/kde/share/doc/HTML/cs/common ; rm -rf fdl-license )
 ( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/fdl-license fdl-license )
 ( cd opt/kde/share/doc/HTML/cs/common ; rm -rf qpl-license.html )
@@ -42,6 +38,8 @@
 ( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/grad.png grad.png )
 ( cd opt/kde/share/doc/HTML/cs/common ; rm -rf kde-web.css )
 ( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf kde_logo_bg.png )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
 ( cd opt/kde/share/doc/HTML/cs/common ; rm -rf lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/cs/common ; rm -rf doxygen.css )
@@ -56,12 +54,16 @@
 ( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/cs/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf appheader.html )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/cs/common ; rm -rf doctop1.png )
 ( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
 ( cd opt/kde/share/doc/HTML/cs/common ; rm -rf doctop2.png )
 ( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
 ( cd opt/kde/share/doc/HTML/cs/common ; rm -rf shadow.png )
 ( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/cs/common ; rm -rf kde_logo.png )
+( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/cs/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/cs/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
 ( cd opt/kde/share/doc/HTML/cs/common ; rm -rf fdl-license.html )
@@ -120,6 +122,8 @@
 ( cd opt/kde/share/doc/HTML/cs/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
 ( cd opt/kde/share/doc/HTML/cs/kdeprint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/cs/kdeprint ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
+( cd opt/kde/share/doc/HTML/cs/kgamma ; rm -rf common )
+( cd opt/kde/share/doc/HTML/cs/kgamma ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
 ( cd opt/kde/share/doc/HTML/cs/kinfocenter/dma ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/cs/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/cs/common common )
 ( cd opt/kde/share/doc/HTML/cs/kinfocenter/pci ; rm -rf common )
